package com.ruoyi.business.service;

import java.util.List;
import com.ruoyi.business.domain.HwElectronicFence;
import com.ruoyi.business.domain.VO.EleMonitorDeviceSumVo;
import com.ruoyi.business.domain.VO.ElectronicFenceVo;
import com.ruoyi.business.domain.VO.ElectronicNumVo;

/**
 * 电子围栏Service接口
 *
 * @author xins
 * @date 2023-09-04
 */
public interface IHwElectronicFenceService
{
    /**
     * 查询电子围栏
     *
     * @param electronicFenceId 电子围栏主键
     * @return 电子围栏
     */
    public HwElectronicFence selectHwElectronicFenceByElectronicFenceId(Long electronicFenceId);
    /**
     * 根据场景查询电子围栏信息
     * */
    public List<HwElectronicFence> selectElectronicByScene(Long sceneId);
    public List<ElectronicFenceVo> selectEleTypeNums(Long sceneId);
    /**
     * 查询电子围栏列表
     *
     * @param hwElectronicFence 电子围栏
     * @return 电子围栏集合
     */
    public List<HwElectronicFence> selectHwElectronicFenceList(HwElectronicFence hwElectronicFence);

    /**
     * 新增电子围栏
     *
     * @param hwElectronicFence 电子围栏
     * @return 结果
     */
    public int insertHwElectronicFence(HwElectronicFence hwElectronicFence);

    /**
     * 修改电子围栏
     *
     * @param hwElectronicFence 电子围栏
     * @return 结果
     */
    public int updateHwElectronicFence(HwElectronicFence hwElectronicFence);

    /**
     * 批量删除电子围栏
     *
     * @param electronicFenceIds 需要删除的电子围栏主键集合
     * @return 结果
     */
    public int deleteHwElectronicFenceByElectronicFenceIds(Long[] electronicFenceIds);

    /**
     * 删除电子围栏信息
     *
     * @param electronicFenceId 电子围栏主键
     * @return 结果
     */
    public int deleteHwElectronicFenceByElectronicFenceId(Long electronicFenceId);
}
